-- Path and file configuration --
path = "sys/lua/mixadmin/"
files = {"config", "functions", "commands"}

-- Load all files (from the files table)
for _, file in pairs(files) do
	dofile(path..""..file..".lua")
end

-- Table with all hooks to be loaded
hooks = {
	"join",
	"say",
	"team",
	"leave",
	"rcon",
	"spawn",
	"parse",
	"startround",
	"hit",
	"endround"
}

-- Loads all hooks of the table
for k,v in pairs(hooks) do
	local hookname = "_"..v
	addhook(v,hookname)
end

-- Initial tables, don't touch
loadAdmins()
lvl = {}
damage = {}
dmg = initArray(32)
total = initArray(32)

for k, v in pairs(admin) do
	print("\169100255100Lua: LoadAdmin - "..k.." (USGN: \'"..v.."\')")
end

-- Functions --

function _join(id)
	setRank(id)
	welcome(id)
end

teams_locked = false
function _team(id, team)
	if teams_locked == true then
		if player(id,"team") == 0 then -- if spec
			msg2(id,info[3].."You cannot join this team. Teams are locked!")
			return 1
		end
	end
end

function _leave(id)
	dmg[id] = 0
	total[id] = 0
	local playerlist = #player(0,"table")
	if teams_locked == true then
		if playerlist == 1 then
			teams_locked = false
			msg(info[1].."There are no players in the server anymore. Teams have been unlocked")
		end
	end
end

function _rcon(cmds, id, ip, port)
	if id > 0 then
		msg(info[4]..""..player(id,"name").." used RCON: \169255150150"..cmds)
		file = assert(io.open(Logpath, "a"),"Failed to open \'"..Logpath.."\'")
		file:write(player(id,"name").." ("..player(id,"usgn")..","..player(id,"ip")..") used RCON: "..cmds.."\n")
		file:flush()
		file:close()
	elseif id == 0 then
		msg(info[4]..""..ip.." used RCON: \169255150150"..cmds)
		file = assert(io.open(Logpath, "a"),"Failed to open \'"..Logpath.."\'")
		file:write("External ("..ip..") RCON: "..cmds.."\n")
		file:flush()
		file:close()
	end
end

function _spawn(id)
	if knife then
		parse("strip "..id.." 1")
		parse("strip "..id.." 2")
		if player(id,"bomb") then
			parse("strip "..id.." Bomb")
		end
	end
end

function _parse(cmd)
	if (cmd == "sv_invisible 1") then
		math.randomseed(os.time())
		parse("sv_lan 1")
		local port = math.random(16666,65535)
		parse("sv_hostport "..port)
		timer(300,"reloadMap")
		for _, v in pairs(player(0, "table")) do
			parse("reroute "..v.." "..ip..":"..port)
		end 
		return 1

	elseif cmd == ("sv_invisible 0") then
		parse("sv_lan 0")
		parse("sv_hostport "..mainport)
		timer(300,"reloadMap")
		for _, v in pairs(player(0, "table")) do
			parse("reroute "..v.." "..ip..":"..mainport)
		end 
		return 1
	end
end

function _startround()
	for _,id in pairs(player(0,"table")) do
		dmg[id] = 0
	end
end

function _hit(id,source,weapon,hpdmg)
	if source == 0 then
		return false
	end

	if player(source,"team") == player(id,"team") then
		return false
	end

	dmg[source] = dmg[source] + hpdmg
end

function _endround(mode)
	playerlist = player(0,"table")
	if mode >= 3 and mode <= 5 then
		for _,id in pairs(playerlist) do
			total[id] = 0
		end
		return false
	end

	local max_val,key =- math.huge
	for k,v in pairs(dmg) do
		if v > max_val then
			max_val,key = v,k
		end
	end

	if max_val == 0 then
		return false
	end

	for _,id in pairs(playerlist) do
		total[id] = total[id] + dmg[id]
		msg2(id,"\169175255100[DAMAGE]:\169255255255 "..player(key,"name").." is MVP "..max_val.." HP")
		if player(id,"team") > 0 then
			msg2(id,"\169175255100[DAMAGE]:\169255255255 in this round "..dmg[id].." HP")
			msg2(id,"\169175255100[DAMAGE]:\169255255255 in total "..total[id].." HP")
		end
	end
end